==> dde-control-center_6.0.20.tar.xz: BUILD/translations/keyboard_language_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <source>Afar</source>
        <translation>Afarski</translation>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>Afrikaans</translation>
    </message>
    <message>
        <source>አማርኛ</source>
        <translation>Amharski (አማርኛ)</translation>
    </message>
    <message>
        <source>عربية</source>
        <translation>Arabski (عربية)</translation>
    </message>
    <message>
        <source>অসমীয়া</source>
        <translation>Asamski (অসমীয়া)</translation>
    </message>
    <message>
        <source>Asturianu</source>
        <translation>Asturyjski</translation>
    </message>
    <message>
        <source>Беларуская</source>
        <translation>Białoruski</translation>
    </message>
    <message>
        <source>Biełaruskaja łacinka</source>
        <translation>Białoruska łacina</translation>
    </message>
    <message>
        <source>Български</source>
        <translation>Bułgarski</translation>
    </message>
    <message>
        <source>বাংলা</source>
        <translation>Bengalski</translation>
    </message>
    <message>
        <source>বাংলা (ভারত)</source>
        <translation>Bengalski (Indie)</translation>
    </message>
    <message>
        <source>བོད་སྐད།</source>
        <translation>Tybetański</translation>
    </message>
    <message>
        <source>Brezhoneg</source>
        <translation>Bretoński</translation>
    </message>
    <message>
        <source>Bosanski</source>
        <translation>Bośniacki</translation>
    </message>
    <message>
        <source>Català</source>
        <translation>Kataloński</translation>
    </message>
    <message>
        <source>Qırımtatarca</source>
        <translation>Krymsko-Turecki</translation>
    </message>
    <message>
        <source>Český</source>
        <translation>Czeski</translation>
    </message>
    <message>
        <source>Kaszëbsczi</source>
        <translation>Kaszubski</translation>
    </message>
    <message>
        <source>Чăвашла</source>
        <translation>Czuwaski</translation>
    </message>
    <message>
        <source>Cymraeg</source>
        <translation>Walijski</translation>
    </message>
    <message>
        <source>Dansk</source>
        <translation>Duński</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Niemiecki</translation>
    </message>
    <message>
        <source>ཇོང་ཁ</source>
        <translation>Dzongkha</translation>
    </message>
    <message>
        <source>Ελληνικά</source>
        <translation>Grecki</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>Brytyjski Angielski</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>Amerykański Angielski</translation>
    </message>
    <message>
        <source>Español</source>
        <translation>Hiszpański</translation>
    </message>
    <message>
        <source>Eesti</source>
        <translation>Estoński</translation>
    </message>
    <message>
        <source>Euskara</source>
        <translation>Baskijski</translation>
    </message>
    <message>
        <source>فارسی</source>
        <translation>Perski</translation>
    </message>
    <message>
        <source>Suomi</source>
        <translation>Fiński</translation>
    </message>
    <message>
        <source>Føroyskt</source>
        <translation>Faroezyjski</translation>
    </message>
    <message>
        <source>Français</source>
        <translation>Francuski</translation>
    </message>
    <message>
        <source>Frysk</source>
        <translation>Zachodnio Fryzyjski</translation>
    </message>
    <message>
        <source>Gaeilge</source>
        <translation>Irlandzki</translation>
    </message>
    <message>
        <source>Gàidhlig</source>
        <translation>Celtycki</translation>
    </message>
    <message>
        <source>Galego</source>
        <translation>Galicyjski</translation>
    </message>
    <message>
        <source>ગુજરાતી </source>
        <translation>Gujarati</translation>
    </message>
    <message>
        <source>Gaelg</source>
        <translation>Mański</translation>
    </message>
    <message>
        <source>هَوُسَ</source>
        <translation>Hausa</translation>
    </message>
    <message>
        <source>עברית</source>
        <translation>Hebrajski</translation>
    </message>
    <message>
        <source>हिन्दी</source>
        <translation>Hinduski</translation>
    </message>
    <message>
        <source>Chhattisgarhi</source>
        <translation>Chhattisgarhi</translation>
    </message>
    <message>
        <source>Hrvatski</source>
        <translation>Chorwacki</translation>
    </message>
    <message>
        <source>Hornjoserbsce</source>
        <translation>Górnołużycki</translation>
    </message>
    <message>
        <source>Magyar</source>
        <translation>Węgierski</translation>
    </message>
    <message>
        <source>Հայերեն</source>
        <translation>Armeński</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonezyjski</translation>
    </message>
    <message>
        <source>Iñupiak</source>
        <translation>Inupiak</translation>
    </message>
    <message>
        <source>Íslenska</source>
        <translation>Islandzki</translation>
    </message>
    <message>
        <source>Italiano</source>
        <translation>Włoski</translation>
    </message>
    <message>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>Inuktitut</translation>
    </message>
    <message>
        <source>日本語</source>
        <translation>Japoński</translation>
    </message>
    <message>
        <source>ქართული</source>
        <translation>Gruziński</translation>
    </message>
    <message>
        <source>Қазақша</source>
        <translation>Kazachski</translation>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation>Grenlandzki</translation>
    </message>
    <message>
        <source>ខ្មែរ</source>
        <translation>Khmer</translation>
    </message>
    <message>
        <source>ಕನ್ನಡ</source>
        <translation>Kannada</translation>
    </message>
    <message>
        <source>한국어</source>
        <translation>Koreański</translation>
    </message>
    <message>
        <source>कश्मीरी - (كشميري)</source>
        <translation>Kaszmirski - (كشميري) </translation>
    </message>
    <message>
        <source>Kurdî</source>
        <translation>Kurdyjski</translation>
    </message>
    <message>
        <source>Kernewek</source>
        <translation>Kornwalijski</translation>
    </message>
    <message>
        <source>Кыргызча</source>
        <translation>Kirgiski</translation>
    </message>
    <message>
        <source>Lëtzebuergesch</source>
        <translation>Luksemburski</translation>
    </message>
    <message>
        <source>Limburgs</source>
        <translation>Lumburgijski</translation>
    </message>
    <message>
        <source>ລາວ</source>
        <translation>Lao</translation>
    </message>
    <message>
        <source>Lietuvių</source>
        <translation>Litewski</translation>
    </message>
    <message>
        <source>Latviešu</source>
        <translation>Łotewski</translation>
    </message>
    <message>
        <source>Maithili</source>
        <translation>Maithili</translation>
    </message>
    <message>
        <source>Malagasy</source>
        <translation>Malagaski</translation>
    </message>
    <message>
        <source>Ebon</source>
        <translation>Ebon</translation>
    </message>
    <message>
        <source>Māori</source>
        <translation>Maori</translation>
    </message>
    <message>
        <source>Македонски</source>
        <translation>Macedoński</translation>
    </message>
    <message>
        <source>മലയാളം</source>
        <translation>Malajalamski</translation>
    </message>
    <message>
        <source>Монгол</source>
        <translation>Mongolski</translation>
    </message>
    <message>
        <source>मराठी</source>
        <translation>Marathi</translation>
    </message>
    <message>
        <source>Bahasa Melayu</source>
        <translation>Malajski</translation>
    </message>
    <message>
        <source>Malti</source>
        <translation>Maltański</translation>
    </message>
    <message>
        <source>Myanmasa</source>
        <translation>Burmisjki</translation>
    </message>
    <message>
        <source>Ekakairũ Naoero</source>
        <translation>Chiński</translation>
    </message>
    <message>
        <source>Norsk (bokmål)</source>
        <translation>Norweski</translation>
    </message>
    <message>
        <source>Plattdüütsch</source>
        <translation>Dolnoniemiecki</translation>
    </message>
    <message>
        <source>नेपाली</source>
        <translation>Nepalski</translation>
    </message>
    <message>
        <source>Nederlands</source>
        <translation>Holenderski</translation>
    </message>
    <message>
        <source>Norsk (nynorsk)</source>
        <translation>Norweski</translation>
    </message>
    <message>
        <source>IsiNdebele</source>
        <translation>Południowy Ndebele</translation>
    </message>
    <message>
        <source>Sesotho sa Leboa</source>
        <translation>Północny sotho</translation>
    </message>
    <message>
        <source>Occitan</source>
        <translation>Oksytański</translation>
    </message>
    <message>
        <source>Oromoo</source>
        <translation>Oromowski</translation>
    </message>
    <message>
        <source>ଓଡ଼ିଆ</source>
        <translation>Orijski</translation>
    </message>
    <message>
        <source>Иронау</source>
        <translation>Osecki</translation>
    </message>
    <message>
        <source>ਪੰਜਾਬੀ</source>
        <translation>Pendżabski</translation>
    </message>
    <message>
        <source>Polski</source>
        <translation>Polski</translation>
    </message>
    <message>
        <source>پښتو</source>
        <translation>Puszto</translation>
    </message>
    <message>
        <source>Português</source>
        <translation>Portugalski</translation>
    </message>
    <message>
        <source>Português do Brasil</source>
        <translation>Portugalski (Brazylijski)</translation>
    </message>
    <message>
        <source>Română</source>
        <translation>Rumuński</translation>
    </message>
    <message>
        <source>Русский</source>
        <translation>Rosyjski</translation>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation>Rwanda</translation>
    </message>
    <message>
        <source>संस्कृत</source>
        <translation>Sanskryt</translation>
    </message>
    <message>
        <source>Sardu</source>
        <translation>Sardyński</translation>
    </message>
    <message>
        <source>سنڌي</source>
        <translation>Sindhi</translation>
    </message>
    <message>
        <source>Sámegiella</source>
        <translation>Północny Sami</translation>
    </message>
    <message>
        <source>සිංහල</source>
        <translation>Syngaleski</translation>
    </message>
    <message>
        <source>Slovenčina</source>
        <translation>Słowacki</translation>
    </message>
    <message>
        <source>Slovenščina</source>
        <translation>Słoweński</translation>
    </message>
    <message>
        <source>Soomaaliga</source>
        <translation>Somalijski</translation>
    </message>
    <message>
        <source>Shqip</source>
        <translation>Albański</translation>
    </message>
    <message>
        <source>Српски</source>
        <translation>Serbski</translation>
    </message>
    <message>
        <source>srpski (latinica)</source>
        <translation>Serbski (Łacina)</translation>
    </message>
    <message>
        <source>SiSwati</source>
        <translation>Swati</translation>
    </message>
    <message>
        <source>Sesotho</source>
        <translation>Południowy Sotho</translation>
    </message>
    <message>
        <source>Svenska</source>
        <translation>Szwedzki</translation>
    </message>
    <message>
        <source>Swahili</source>
        <translation>Suahili</translation>
    </message>
    <message>
        <source>தமிழ்</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <source>తెలుగు</source>
        <translation>Telugu</translation>
    </message>
    <message>
        <source>Тоҷикӣ</source>
        <translation>Tadżycki</translation>
    </message>
    <message>
        <source>ภาษาไทย</source>
        <translation>Tajlandzki</translation>
    </message>
    <message>
        <source>ትግርኛ</source>
        <translation>Tigrinia</translation>
    </message>
    <message>
        <source>Türkmen</source>
        <translation>Turecki</translation>
    </message>
    <message>
        <source>Setswana</source>
        <translation>Tswana</translation>
    </message>
    <message>
        <source>Türkçe</source>
        <translation>Turecki</translation>
    </message>
    <message>
        <source>Xitsonga</source>
        <translation>Tsonga</translation>
    </message>
    <message>
        <source>Татарский</source>
        <translation>Tatarski</translation>
    </message>
    <message>
        <source>ئۇيغۇرچە</source>
        <translation>Ujgurski</translation>
    </message>
    <message>
        <source>Українська</source>
        <translation>Ukraiński</translation>
    </message>
    <message>
        <source>اردو</source>
        <translation>Urdu</translation>
    </message>
    <message>
        <source>Oʻzbekcha</source>
        <translation>Uzbecki</translation>
    </message>
    <message>
        <source>Uzbek (Cyrillic)</source>
        <translation>Uzbecki (Cyrylica)</translation>
    </message>
    <message>
        <source>Venda</source>
        <translation>Venda</translation>
    </message>
    <message>
        <source>Tiếng Việt</source>
        <translation>Wietnamski</translation>
    </message>
    <message>
        <source>Walon</source>
        <translation>Walon</translation>
    </message>
    <message>
        <source>Wolof</source>
        <translation>Wolof</translation>
    </message>
    <message>
        <source>isixhosa</source>
        <translation>Xhosa</translation>
    </message>
    <message>
        <source>ייִדיש</source>
        <translation>Jidysz</translation>
    </message>
    <message>
        <source>Yorùbá</source>
        <translation>Yoruba</translation>
    </message>
    <message>
        <source>简体中文</source>
        <translation>Chiński uproszczony</translation>
    </message>
    <message>
        <source>繁體中文（中國香港）</source>
        <translation>Chiński tradycyjny (Hong Kong SAR, Chiny)</translation>
    </message>
    <message>
        <source>繁體中文（中國臺灣）</source>
        <translation>Chiński tradycyjny (Tajwan, Chiny)</translation>
    </message>
    <message>
        <source>isiZulu</source>
        <translation>Zulu</translation>
    </message>
</context>
</TS>

==> dde-control-center_6.0.78.1.tar.xz: BUILD/translations/keyboard_language_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <source>Afar</source>
        <translation>Afarski</translation>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>Afrikaans</translation>
    </message>
    <message>
        <source>አማርኛ</source>
        <translation>Amharski (አማርኛ)</translation>
    </message>
    <message>
        <source>عربية</source>
        <translation>Arabski (عربية)</translation>
    </message>
    <message>
        <source>অসমীয়া</source>
        <translation>Asamski (অসমীয়া)</translation>
    </message>
    <message>
        <source>Asturianu</source>
        <translation>Asturyjski</translation>
    </message>
    <message>
        <source>Беларуская</source>
        <translation>Białoruski</translation>
    </message>
    <message>
        <source>Biełaruskaja łacinka</source>
        <translation>Białoruska łacina</translation>
    </message>
    <message>
        <source>Български</source>
        <translation>Bułgarski</translation>
    </message>
    <message>
        <source>বাংলা</source>
        <translation>Bengalski</translation>
    </message>
    <message>
        <source>বাংলা (ভারত)</source>
        <translation>Bengalski (Indie)</translation>
    </message>
    <message>
        <source>བོད་སྐད།</source>
        <translation>Tybetański</translation>
    </message>
    <message>
        <source>Brezhoneg</source>
        <translation>Bretoński</translation>
    </message>
    <message>
        <source>Bosanski</source>
        <translation>Bośniacki</translation>
    </message>
    <message>
        <source>Català</source>
        <translation>Kataloński</translation>
    </message>
    <message>
        <source>Qırımtatarca</source>
        <translation>Krymsko-Turecki</translation>
    </message>
    <message>
        <source>Český</source>
        <translation>Czeski</translation>
    </message>
    <message>
        <source>Kaszëbsczi</source>
        <translation>Kaszubski</translation>
    </message>
    <message>
        <source>Чăвашла</source>
        <translation>Czuwaski</translation>
    </message>
    <message>
        <source>Cymraeg</source>
        <translation>Walijski</translation>
    </message>
    <message>
        <source>Dansk</source>
        <translation>Duński</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Niemiecki</translation>
    </message>
    <message>
        <source>ཇོང་ཁ</source>
        <translation>Dzongkha</translation>
    </message>
    <message>
        <source>Ελληνικά</source>
        <translation>Grecki</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>Brytyjski Angielski</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>Amerykański Angielski</translation>
    </message>
    <message>
        <source>Español</source>
        <translation>Hiszpański</translation>
    </message>
    <message>
        <source>Eesti</source>
        <translation>Estoński</translation>
    </message>
    <message>
        <source>Euskara</source>
        <translation>Baskijski</translation>
    </message>
    <message>
        <source>فارسی</source>
        <translation>Perski</translation>
    </message>
    <message>
        <source>Suomi</source>
        <translation>Fiński</translation>
    </message>
    <message>
        <source>Føroyskt</source>
        <translation>Faroezyjski</translation>
    </message>
    <message>
        <source>Français</source>
        <translation>Francuski</translation>
    </message>
    <message>
        <source>Frysk</source>
        <translation>Zachodnio Fryzyjski</translation>
    </message>
    <message>
        <source>Gaeilge</source>
        <translation>Irlandzki</translation>
    </message>
    <message>
        <source>Gàidhlig</source>
        <translation>Celtycki</translation>
    </message>
    <message>
        <source>Galego</source>
        <translation>Galicyjski</translation>
    </message>
    <message>
        <source>ગુજરાતી </source>
        <translation>Gujarati</translation>
    </message>
    <message>
        <source>Gaelg</source>
        <translation>Mański</translation>
    </message>
    <message>
        <source>هَوُسَ</source>
        <translation>Hausa</translation>
    </message>
    <message>
        <source>עברית</source>
        <translation>Hebrajski</translation>
    </message>
    <message>
        <source>हिन्दी</source>
        <translation>Hinduski</translation>
    </message>
    <message>
        <source>Chhattisgarhi</source>
        <translation>Chhattisgarhi</translation>
    </message>
    <message>
        <source>Hrvatski</source>
        <translation>Chorwacki</translation>
    </message>
    <message>
        <source>Hornjoserbsce</source>
        <translation>Górnołużycki</translation>
    </message>
    <message>
        <source>Magyar</source>
        <translation>Węgierski</translation>
    </message>
    <message>
        <source>Հայերեն</source>
        <translation>Armeński</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonezyjski</translation>
    </message>
    <message>
        <source>Iñupiak</source>
        <translation>Inupiak</translation>
    </message>
    <message>
        <source>Íslenska</source>
        <translation>Islandzki</translation>
    </message>
    <message>
        <source>Italiano</source>
        <translation>Włoski</translation>
    </message>
    <message>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>Inuktitut</translation>
    </message>
    <message>
        <source>日本語</source>
        <translation>Japoński</translation>
    </message>
    <message>
        <source>ქართული</source>
        <translation>Gruziński</translation>
    </message>
    <message>
        <source>Қазақша</source>
        <translation>Kazachski</translation>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation>Grenlandzki</translation>
    </message>
    <message>
        <source>ខ្មែរ</source>
        <translation>Khmer</translation>
    </message>
    <message>
        <source>ಕನ್ನಡ</source>
        <translation>Kannada</translation>
    </message>
    <message>
        <source>한국어</source>
        <translation>Koreański</translation>
    </message>
    <message>
        <source>कश्मीरी - (كشميري)</source>
        <translation>Kaszmirski - (كشميري) </translation>
    </message>
    <message>
        <source>Kurdî</source>
        <translation>Kurdyjski</translation>
    </message>
    <message>
        <source>Kernewek</source>
        <translation>Kornwalijski</translation>
    </message>
    <message>
        <source>Кыргызча</source>
        <translation>Kirgiski</translation>
    </message>
    <message>
        <source>Lëtzebuergesch</source>
        <translation>Luksemburski</translation>
    </message>
    <message>
        <source>Limburgs</source>
        <translation>Lumburgijski</translation>
    </message>
    <message>
        <source>ລາວ</source>
        <translation>Lao</translation>
    </message>
    <message>
        <source>Lietuvių</source>
        <translation>Litewski</translation>
    </message>
    <message>
        <source>Latviešu</source>
        <translation>Łotewski</translation>
    </message>
    <message>
        <source>Maithili</source>
        <translation>Maithili</translation>
    </message>
    <message>
        <source>Malagasy</source>
        <translation>Malagaski</translation>
    </message>
    <message>
        <source>Ebon</source>
        <translation>Ebon</translation>
    </message>
    <message>
        <source>Māori</source>
        <translation>Maori</translation>
    </message>
    <message>
        <source>Македонски</source>
        <translation>Macedoński</translation>
    </message>
    <message>
        <source>മലയാളം</source>
        <translation>Malajalamski</translation>
    </message>
    <message>
        <source>Монгол</source>
        <translation>Mongolski</translation>
    </message>
    <message>
        <source>मराठी</source>
        <translation>Marathi</translation>
    </message>
    <message>
        <source>Bahasa Melayu</source>
        <translation>Malajski</translation>
    </message>
    <message>
        <source>Malti</source>
        <translation>Maltański</translation>
    </message>
    <message>
        <source>Myanmasa</source>
        <translation>Burmisjki</translation>
    </message>
    <message>
        <source>Ekakairũ Naoero</source>
        <translation>Chiński</translation>
    </message>
    <message>
        <source>Norsk (bokmål)</source>
        <translation>Norweski</translation>
    </message>
    <message>
        <source>Plattdüütsch</source>
        <translation>Dolnoniemiecki</translation>
    </message>
    <message>
        <source>नेपाली</source>
        <translation>Nepalski</translation>
    </message>
    <message>
        <source>Nederlands</source>
        <translation>Holenderski</translation>
    </message>
    <message>
        <source>Norsk (nynorsk)</source>
        <translation>Norweski</translation>
    </message>
    <message>
        <source>IsiNdebele</source>
        <translation>Południowy Ndebele</translation>
    </message>
    <message>
        <source>Sesotho sa Leboa</source>
        <translation>Północny sotho</translation>
    </message>
    <message>
        <source>Occitan</source>
        <translation>Oksytański</translation>
    </message>
    <message>
        <source>Oromoo</source>
        <translation>Oromowski</translation>
    </message>
    <message>
        <source>ଓଡ଼ିଆ</source>
        <translation>Orijski</translation>
    </message>
    <message>
        <source>Иронау</source>
        <translation>Osecki</translation>
    </message>
    <message>
        <source>ਪੰਜਾਬੀ</source>
        <translation>Pendżabski</translation>
    </message>
    <message>
        <source>Polski</source>
        <translation>Polski</translation>
    </message>
    <message>
        <source>پښتو</source>
        <translation>Puszto</translation>
    </message>
    <message>
        <source>Português</source>
        <translation>Portugalski</translation>
    </message>
    <message>
        <source>Português do Brasil</source>
        <translation>Portugalski (Brazylijski)</translation>
    </message>
    <message>
        <source>Română</source>
        <translation>Rumuński</translation>
    </message>
    <message>
        <source>Русский</source>
        <translation>Rosyjski</translation>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation>Rwanda</translation>
    </message>
    <message>
        <source>संस्कृत</source>
        <translation>Sanskryt</translation>
    </message>
    <message>
        <source>Sardu</source>
        <translation>Sardyński</translation>
    </message>
    <message>
        <source>سنڌي</source>
        <translation>Sindhi</translation>
    </message>
    <message>
        <source>Sámegiella</source>
        <translation>Północny Sami</translation>
    </message>
    <message>
        <source>සිංහල</source>
        <translation>Syngaleski</translation>
    </message>
    <message>
        <source>Slovenčina</source>
        <translation>Słowacki</translation>
    </message>
    <message>
        <source>Slovenščina</source>
        <translation>Słoweński</translation>
    </message>
    <message>
        <source>Soomaaliga</source>
        <translation>Somalijski</translation>
    </message>
    <message>
        <source>Shqip</source>
        <translation>Albański</translation>
    </message>
    <message>
        <source>Српски</source>
        <translation>Serbski</translation>
    </message>
    <message>
        <source>srpski (latinica)</source>
        <translation>Serbski (Łacina)</translation>
    </message>
    <message>
        <source>SiSwati</source>
        <translation>Swati</translation>
    </message>
    <message>
        <source>Sesotho</source>
        <translation>Południowy Sotho</translation>
    </message>
    <message>
        <source>Svenska</source>
        <translation>Szwedzki</translation>
    </message>
    <message>
        <source>Swahili</source>
        <translation>Suahili</translation>
    </message>
    <message>
        <source>தமிழ்</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <source>తెలుగు</source>
        <translation>Telugu</translation>
    </message>
    <message>
        <source>Тоҷикӣ</source>
        <translation>Tadżycki</translation>
    </message>
    <message>
        <source>ภาษาไทย</source>
        <translation>Tajlandzki</translation>
    </message>
    <message>
        <source>ትግርኛ</source>
        <translation>Tigrinia</translation>
    </message>
    <message>
        <source>Türkmen</source>
        <translation>Turecki</translation>
    </message>
    <message>
        <source>Setswana</source>
        <translation>Tswana</translation>
    </message>
    <message>
        <source>Türkçe</source>
        <translation>Turecki</translation>
    </message>
    <message>
        <source>Xitsonga</source>
        <translation>Tsonga</translation>
    </message>
    <message>
        <source>Татарский</source>
        <translation>Tatarski</translation>
    </message>
    <message>
        <source>ئۇيغۇرچە</source>
        <translation>Ujgurski</translation>
    </message>
    <message>
        <source>Українська</source>
        <translation>Ukraiński</translation>
    </message>
    <message>
        <source>اردو</source>
        <translation>Urdu</translation>
    </message>
    <message>
        <source>Oʻzbekcha</source>
        <translation>Uzbecki</translation>
    </message>
    <message>
        <source>Uzbek (Cyrillic)</source>
        <translation>Uzbecki (Cyrylica)</translation>
    </message>
    <message>
        <source>Venda</source>
        <translation>Venda</translation>
    </message>
    <message>
        <source>Tiếng Việt</source>
        <translation>Wietnamski</translation>
    </message>
    <message>
        <source>Walon</source>
        <translation>Walon</translation>
    </message>
    <message>
        <source>Wolof</source>
        <translation>Wolof</translation>
    </message>
    <message>
        <source>isixhosa</source>
        <translation>Xhosa</translation>
    </message>
    <message>
        <source>ייִדיש</source>
        <translation>Jidysz</translation>
    </message>
    <message>
        <source>Yorùbá</source>
        <translation>Yoruba</translation>
    </message>
    <message>
        <source>简体中文</source>
        <translation>Chiński uproszczony</translation>
    </message>
    <message>
        <source>繁體中文（中國香港）</source>
        <translation>Chiński tradycyjny (Hong Kong)</translation>
    </message>
    <message>
        <source>繁體中文（中國臺灣）</source>
        <translation>Chiński tradycyjny (Hong Kong)</translation>
    </message>
    <message>
        <source>isiZulu</source>
        <translation>Zulu</translation>
    </message>
</context>
</TS>
